@@ -118,7 +118,7 @@ void set_disk_output_unit(void)
 		return;
 
 	/* Check POSIXLY_CORRECT environment variable */
-	if (getenv(ENV_POSIXLY_CORRECT) == NULL) {
+	if (__getenv(ENV_POSIXLY_CORRECT) == NULL) {
 		/* Variable not set: Unit is kB/s and not blocks/s */
 		flags |= I_D_KILOBYTES;
 	}
@@ -375,18 +375,18 @@ void io_sys_init(int *iodev_nr)
  * @dlist_idx	Number of devices entered on the command line.
  ***************************************************************************
  */
-void presave_device_list(int iodev_nr, int dlist_idx)
+void presave_device_list(int iodev_nr, int *dlist_idx)
 {
 	int i;
 	struct io_hdr_stats *shi = st_hdr_iodev;
 	struct io_dlist *sdli = st_dev_list;
 
-	if (dlist_idx>0) {
+	if (*dlist_idx > 0) {
 		/* First, save the last group name entered on the command line in the list */
-		update_dev_list(&dlist_idx, group_name);
+		update_dev_list(dlist_idx, group_name);
 
 		/* Now save devices and group names in the io_hdr_stats structures */
-		for (i = 0; (i < dlist_idx) && (i < iodev_nr); i++, shi++, sdli++) {
+		for (i = 0; (i < *dlist_idx) && (i < iodev_nr); i++, shi++, sdli++) {
 			strncpy(shi->name, sdli->dev_name, MAX_NAME_LEN);
 			shi->name[MAX_NAME_LEN - 1] = '\0';
 			shi->used = TRUE;
@@ -1918,9 +1918,6 @@ void rw_io_stat_loop(long int count, struct tm *rectime, int iodev_nr, int dlist
 				count--;
 			}
 		}
-		else {
-			skip = 0;
-		}
 
 		if (count) {
 			curr ^= 1;
@@ -1930,9 +1927,10 @@ void rw_io_stat_loop(long int count, struct tm *rectime, int iodev_nr, int dlist
 				/* SIGINT signal caught => Terminate JSON output properly */
 				count = 0;
 			}
-			else if (DISPLAY_JSON_OUTPUT(flags) && count) {
+			else if (DISPLAY_JSON_OUTPUT(flags) && count && !skip) {
 				printf(",");
 			}
+			skip = 0;
 		}
 		printf("\n");
 	}
@@ -2277,13 +2275,13 @@ int main(int argc, char **argv)
 		 * If groups of devices have been defined
 		 * then save devices and groups in the list.
 		 */
-		presave_device_list(iodev_nr, dlist_idx);
+		presave_device_list(iodev_nr, &dlist_idx);
 	}
 
 	get_localtime(&rectime, 0);
 
 	/* Get system name, release number and hostname */
-	uname(&header);
+	__uname(&header);
 	if (print_gal_header(&rectime, header.sysname, header.release,
 			     header.nodename, header.machine, cpu_nr,
 			     DISPLAY_JSON_OUTPUT(flags))) {
