@@ -573,6 +573,90 @@ __print_funct_t pcp_print_queue_stats(struct activity *a, int curr, unsigned lon
 #endif	/* HAVE_PCP */
 }
 
+/*
+ ***************************************************************************
+ * Display disks statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_disk_stats(struct activity *a, int curr, unsigned long long itv,
+				     struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i, j;
+	struct stats_disk *sdc,	*sdp, sdpzero;
+	struct ext_disk_stats xds;
+	char *dev_name;
+	char buf[64];
+
+	memset(&sdpzero, 0, STATS_DISK_SIZE);
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		sdc = (struct stats_disk *) ((char *) a->buf[curr] + i * a->msize);
+
+		j = check_disk_reg(a, curr, !curr, i);
+		if (j < 0) {
+			/* This is a newly registered interface. Previous stats are zero */
+			sdp = &sdpzero;
+		}
+		else {
+			sdp = (struct stats_disk *) ((char *) a->buf[!curr] + j * a->msize);
+		}
+
+		/* Get device name */
+		dev_name = get_sa_devname(sdc->major, sdc->minor, flags);
+
+		if (a->item_list != NULL) {
+			/* A list of devices has been entered on the command line */
+			if (!search_list_item(a->item_list, dev_name))
+				/* Device not found */
+				continue;
+		}
+
+		/* Compute extended statistics values */
+		compute_ext_disk_stats(sdc, sdp, itv, &xds);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sdp->nr_ios, sdc->nr_ios, itv));
+		pmiPutValue("disk.device.tps", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sdp->rd_sect, sdc->rd_sect, itv) / 2);
+		pmiPutValue("disk.device.read_bytes", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sdp->wr_sect, sdc->wr_sect, itv) / 2);
+		pmiPutValue("disk.device.write_bytes", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sdp->dc_sect, sdc->dc_sect, itv) / 2);
+		pmiPutValue("disk.device.discard_bytes", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 xds.arqsz / 2);
+		pmiPutValue("disk.device.areq_sz", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sdp->rq_ticks, sdc->rq_ticks, itv) / 1000.0);
+		pmiPutValue("disk.device.aqu_sz", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 xds.await);
+		pmiPutValue("disk.device.await", dev_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 xds.util / 10.0);
+		pmiPutValue("disk.device.util", dev_name, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
 /*
  ***************************************************************************
  * Display network interfaces statistics in PCP format.
@@ -1736,6 +1820,280 @@ __print_funct_t pcp_print_pwr_cpufreq_stats(struct activity *a, int curr, unsign
 #endif	/* HAVE_PCP */
 }
 
+/*
+ ***************************************************************************
+ * Display fan statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_pwr_fan_stats(struct activity *a, int curr, unsigned long long itv,
+					struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i;
+	struct stats_pwr_fan *spc;
+	char buf[64], instance[32];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		spc = (struct stats_pwr_fan *) ((char *) a->buf[curr] + i * a->msize);
+		sprintf(instance, "fan%d", i + 1);
+
+		snprintf(buf, sizeof(buf), "%llu",
+			 (unsigned long long) spc->rpm);
+		pmiPutValue("power.fan.rpm", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%llu",
+			 (unsigned long long) (spc->rpm - spc->rpm_min));
+		pmiPutValue("power.fan.drpm", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%s",
+			spc->device);
+		pmiPutValue("power.fan.device", instance, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Display temperature statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_pwr_temp_stats(struct activity *a, int curr, unsigned long long itv,
+					 struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i;
+	struct stats_pwr_temp *spc;
+	char buf[64], instance[32];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		spc = (struct stats_pwr_temp *) ((char *) a->buf[curr] + i * a->msize);
+		sprintf(instance, "temp%d", i + 1);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 spc->temp);
+		pmiPutValue("power.temp.degC", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 (spc->temp_max - spc->temp_min) ?
+			 (spc->temp - spc->temp_min) / (spc->temp_max - spc->temp_min) * 100 :
+			 0.0);
+		pmiPutValue("power.temp.temp_pct", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%s",
+			spc->device);
+		pmiPutValue("power.temp.device", instance, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Display voltage inputs statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_pwr_in_stats(struct activity *a, int curr, unsigned long long itv,
+				       struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i;
+	struct stats_pwr_in *spc;
+	char buf[64], instance[32];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		spc = (struct stats_pwr_in *) ((char *) a->buf[curr] + i * a->msize);
+		sprintf(instance, "in%d", i);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 spc->in);
+		pmiPutValue("power.in.inV", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 (spc->in_max - spc->in_min) ?
+			 (spc->in - spc->in_min) / (spc->in_max - spc->in_min) * 100 :
+			 0.0);
+		pmiPutValue("power.in.in_pct", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%s",
+			spc->device);
+		pmiPutValue("power.in.device", instance, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Display huge pages statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_huge_stats(struct activity *a, int curr, unsigned long long itv,
+				     struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	char buf[64];
+	struct stats_huge
+		*smc = (struct stats_huge *) a->buf[curr];
+
+	snprintf(buf, sizeof(buf), "%llu", smc->frhkb);
+	pmiPutValue("mem.huge.free", NULL, buf);
+
+	snprintf(buf, sizeof(buf), "%llu", smc->tlhkb - smc->frhkb);
+	pmiPutValue("mem.huge.used", NULL, buf);
+
+	snprintf(buf, sizeof(buf), "%f", smc->tlhkb ? SP_VALUE(smc->frhkb, smc->tlhkb, smc->tlhkb) : 0.0);
+	pmiPutValue("mem.huge.used_pct", NULL, buf);
+
+	snprintf(buf, sizeof(buf), "%llu", smc->rsvdhkb);
+	pmiPutValue("mem.huge.reserved", NULL, buf);
+
+	snprintf(buf, sizeof(buf), "%llu", smc->surphkb);
+	pmiPutValue("mem.huge.surplus", NULL, buf);
+#endif	/* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Display USB devices in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_pwr_usb_stats(struct activity *a, int curr, unsigned long long itv,
+					struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i;
+	struct stats_pwr_usb *suc;
+	char buf[64], instance[32];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		suc = (struct stats_pwr_usb *) ((char *) a->buf[curr] + i * a->msize);
+		sprintf(instance, "usb%d", i);
+
+		snprintf(buf, sizeof(buf), "%d", suc->bus_nr);
+		pmiPutValue("power.usb.bus", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%x", suc->vendor_id);
+		pmiPutValue("power.usb.vendorId", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%x", suc->product_id);
+		pmiPutValue("power.usb.productId", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%u", suc->bmaxpower << 1);
+		pmiPutValue("power.usb.maxpower", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%s", suc->manufacturer);
+		pmiPutValue("power.usb.manufacturer", instance, buf);
+
+		snprintf(buf, sizeof(buf), "%s", suc->product);
+		pmiPutValue("power.usb.productName", instance, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Display filesystem statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_filesystem_stats(struct activity *a, int curr, unsigned long long itv,
+					   struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i;
+	struct stats_filesystem *sfc;
+	char buf[64];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		sfc = (struct stats_filesystem *) ((char *) a->buf[curr] + i * a->msize);
+
+		if (a->item_list != NULL) {
+			/* A list of devices has been entered on the command line */
+			if (!search_list_item(a->item_list,
+					      DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name))
+				/* Device not found */
+				continue;
+		}
+
+		snprintf(buf, sizeof(buf), "%.0f",
+			 (double) sfc->f_bfree / 1024 / 1024);
+		pmiPutValue("fs.util.fsfree",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%.0f",
+			 (double) (sfc->f_blocks - sfc->f_bfree) / 1024 / 1024);
+		pmiPutValue("fs.util.fsused",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 sfc->f_blocks ? SP_VALUE(sfc->f_bfree, sfc->f_blocks, sfc->f_blocks)
+				       : 0.0);
+		pmiPutValue("fs.util.fsused_pct",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 sfc->f_blocks ? SP_VALUE(sfc->f_bavail, sfc->f_blocks, sfc->f_blocks)
+				       : 0.0);
+		pmiPutValue("fs.util.ufsused_pct",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%llu",
+			 sfc->f_ffree);
+		pmiPutValue("fs.util.ifree",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%llu",
+			 sfc->f_files - sfc->f_ffree);
+		pmiPutValue("fs.util.iused",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 sfc->f_files ? SP_VALUE(sfc->f_ffree, sfc->f_files, sfc->f_files)
+				      : 0.0);
+		pmiPutValue("fs.util.iused_pct",
+			    DISPLAY_MOUNT(a->opt_flags) ? sfc->mountp : sfc->fs_name, buf);
+	}
+#endif	/* HAVE_PCP */
+}
+
 /*
  ***************************************************************************
  * Display softnet statistics in PCP format.
@@ -1810,3 +2168,73 @@ __print_funct_t pcp_print_softnet_stats(struct activity *a, int curr, unsigned l
 	}
 #endif	/* HAVE_PCP */
 }
+
+/*
+ ***************************************************************************
+ * Display Fibre Channel HBA statistics in PCP format.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ * @curr	Index in array for current sample statistics.
+ * @itv		Interval of time in 1/100th of a second.
+ * @record_hdr	Record header for current sample.
+ ***************************************************************************
+ */
+__print_funct_t pcp_print_fchost_stats(struct activity *a, int curr, unsigned long long itv,
+				       struct record_header *record_hdr)
+{
+#ifdef HAVE_PCP
+	int i, j, j0, found;
+	struct stats_fchost *sfcc, *sfcp;
+	char buf[64];
+
+	for (i = 0; i < a->nr[curr]; i++) {
+
+		found = FALSE;
+
+		if (a->nr[!curr] > 0) {
+			sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
+
+			/* Look for corresponding structure in previous iteration */
+			j = i;
+
+			if (j >= a->nr[!curr]) {
+				j = a->nr[!curr] - 1;
+			}
+
+			j0 = j;
+
+			do {
+				sfcp = (struct stats_fchost *) ((char *) a->buf[!curr] + j * a->msize);
+				if (!strcmp(sfcc->fchost_name, sfcp->fchost_name)) {
+					found = TRUE;
+					break;
+				}
+				if (++j >= a->nr[!curr]) {
+					j = 0;
+				}
+			}
+			while (j != j0);
+		}
+
+		if (!found)
+			continue;
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv));
+		pmiPutValue("network.fchost.in.frame", sfcc->fchost_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sfcp->f_txframes, sfcc->f_txframes, itv));
+		pmiPutValue("network.fchost.out.frame", sfcc->fchost_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sfcp->f_rxwords, sfcc->f_rxwords, itv));
+		pmiPutValue("network.fchost.in.word", sfcc->fchost_name, buf);
+
+		snprintf(buf, sizeof(buf), "%f",
+			 S_VALUE(sfcp->f_txwords, sfcc->f_txwords, itv));
+		pmiPutValue("network.fchost.out.word", sfcc->fchost_name, buf);
+	}
+#endif	/* HAVE_PCP */
+}
