@@ -54,6 +54,10 @@
 char *sccsid(void) { return (SCCSID); }
 #endif
 
+#ifdef TEST
+extern time_t __unix_time;
+#endif
+
 long interval = 0;
 unsigned int flags = 0;
 
@@ -222,7 +226,7 @@ void parse_sadc_S_option(char *argv[], int opt)
  */
 void alarm_handler(int sig)
 {
-	alarm(interval);
+	__alarm(interval);
 }
 
 /*
@@ -503,7 +507,7 @@ void setup_file_hdr(int fd)
 	file_hdr.sa_cpu_nr = act[get_activity_position(act, A_CPU, EXIT_IF_NOT_FOUND)]->nr_ini;
 
 	/* Get system name, release number, hostname and machine architecture */
-	uname(&header);
+	__uname(&header);
 	strncpy(file_hdr.sa_sysname, header.sysname, UTSNAME_LEN);
 	file_hdr.sa_sysname[UTSNAME_LEN - 1]  = '\0';
 	strncpy(file_hdr.sa_nodename, header.nodename, UTSNAME_LEN);
@@ -921,7 +925,7 @@ void open_ofile(int *ofd, char ofile[], int restart_mark)
 		}
 
 		if ((file_act[i].has_nr && (act[p]->f_count_index < 0)) ||
-		    (!file_act[i].has_nr && (act[p]->f_count_index >=0))) {
+		    (!file_act[i].has_nr && (act[p]->f_count_index >= 0))) {
 #ifdef DEBUG
 			fprintf(stderr, "%s: %s: has_nr=%d count_index=%d\n",
 				__FUNCTION__, act[p]->name, file_act[i].has_nr, act[p]->f_count_index);
@@ -954,8 +958,11 @@ void open_ofile(int *ofd, char ofile[], int restart_mark)
 		 * Since we are appending data to a file, set @nr_ini to the value of the file.
 		 * Stats saved in file will all be 0 for that activity if no items exist on
 		 * the machine.
+		 * NB: We must preserve the value read for A_CPU when a LINUX RESTART is inserted.
 		 */
-		act[p]->nr_ini = file_act[i].nr;
+		if (!ALWAYS_COUNT_ITEMS(act[p]->options) || !act[p]->nr_ini) {
+			act[p]->nr_ini = file_act[i].nr;
+		}
 
 		/*
 		 * Force number of sub-items to that of the file, and reallocate structures.
@@ -1123,7 +1130,7 @@ void rw_sa_stat_loop(long count, int stdfd, int ofd, char ofile[],
 
 		if (count) {
 			/* Wait for a signal (probably SIGALRM or SIGINT) */
-			pause();
+			__pause();
 		}
 
 		if (sigint_caught)
@@ -1162,6 +1169,10 @@ int main(int argc, char **argv)
 	int restart_mark;
 	long count = 0;
 
+#ifdef TEST
+	fprintf(stderr, "TEST MODE\n");
+#endif
+
 	/* Get HZ */
 	get_HZ();
 
@@ -1228,6 +1239,15 @@ int main(int argc, char **argv)
 			}
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--unix_time=", 12)) {
+			if (strspn(argv[opt] + 12, DIGITS) != strlen(argv[opt] + 12)) {
+				usage(argv[0]);
+			}
+			__unix_time = atoll(argv[opt] + 12);
+		}
+#endif
+
 		else if (strspn(argv[opt], DIGITS) != strlen(argv[opt])) {
 			if (ofile[0] || WANT_SA_ROTAT(flags)) {
 				/* Outfile already specified */
@@ -1370,7 +1390,7 @@ int main(int argc, char **argv)
 	memset(&alrm_act, 0, sizeof(alrm_act));
 	alrm_act.sa_handler = alarm_handler;
 	sigaction(SIGALRM, &alrm_act, NULL);
-	alarm(interval);
+	__alarm(interval);
 
 	/* Main loop */
 	rw_sa_stat_loop(count, stdfd, ofd, ofile, sa_dir);
